@@ -6,7 +6,7 @@ from typing import Union, List
 from openpyxl import load_workbook, Workbook
 from openpyxl.utils import column_index_from_string
 
-from .base import BaseRecorder, _data_to_list, _parse_coord, _process_content
+from .base import BaseRecorder, _parse_coord, _process_content
 
 
 class Filler(BaseRecorder):
@@ -29,7 +29,8 @@ class Filler(BaseRecorder):
         :param sign: 按这个值判断是否已填数据
         :param data_col: 要填入数据的第一列，从1开始
         """
-        super().__init__(path, cache_size)
+        super().__init__(None, cache_size)
+        super().set_path(path)
         self.key_cols = key_cols
         self.begin_row = begin_row
         self.sign_col = sign_col
@@ -92,10 +93,10 @@ class Filler(BaseRecorder):
 
     def set_path(self,
                  path: Union[str, Path],
-                 key_cols: Union[str, int, list, tuple] = 1,
+                 key_cols: Union[str, int, list, tuple] = None,
                  begin_row: int = None,
                  sign_col: Union[str, int] = None,
-                 sign: str = None,
+                 sign: Union[int, float, str] = None,
                  data_col: int = None) -> None:
         """设置文件路径                             \n
         :param path: 保存的文件路径
@@ -105,16 +106,17 @@ class Filler(BaseRecorder):
         :param sign: 按这个值判断是否已填数据
         :param data_col: 要填入数据的第一列
         """
-        if not Path(path).exists():
+        if not path or not Path(path).exists():
             raise FileNotFoundError('文件不存在')
+        super().set_path(path)
+        self.key_cols = key_cols or self.key_cols
         self.begin_row = begin_row or self.begin_row
         self.sign_col = sign_col or self.sign_col
         self.sign = sign or self.sign
-        self.data_col = sign or self.data_col
-        self.__init__(path, self.cache_size, key_cols, begin_row, sign_col, sign, data_col)
+        self.data_col = data_col or self.data_col
 
     def add_data(self,
-                 data: Union[list, tuple, dict, int, str, float],
+                 data: Union[list, tuple, dict],
                  coord: Union[list, tuple, str, int] = None) -> None:
         """添加数据                                                                   \n
         数据格式：第一位为行号或坐标（int或str），第二位开始为数据，数据可以是list, tuple, dict
@@ -122,8 +124,8 @@ class Filler(BaseRecorder):
         :param coord: 要添加数据的坐标，仅用于添加一行数据
         :return: None
         """
-        if not data:
-            return
+        if not isinstance(data, (list, tuple, dict)):
+            raise TypeError(f'只能接受list、tuple和dict格式数据，不能是{type(data)}')
 
         if coord is not None:
             coord = _parse_coord(coord, self.data_col)
@@ -202,15 +204,15 @@ class Filler(BaseRecorder):
 
         for i in self._data:
             if i[0] == 'set_link':
-                row, col = _parse_coord(i[1], col)
-                cell = ws.cell(row, col)
+                row, col1 = _parse_coord(i[1], col)
+                cell = ws.cell(row, col1)
                 cell.hyperlink = i[2]
                 if i[3] is not None:
-                    cell.value = i[3]
+                    cell.value = _process_content(i[3], True)
             else:
-                row, col = _parse_coord(i[0], col, (list, tuple))
-                for key, j in enumerate(_data_to_list(i[1:], self._before, self._after)):
-                    ws.cell(row, col + key).value = _process_content(j)
+                row, col1 = _parse_coord(i[0], col, (list, tuple))
+                for key, j in enumerate(self._data_to_list(i[1:])):
+                    ws.cell(row, col1 + key).value = _process_content(j, True)
 
         wb.save(self.path)
         wb.close()
@@ -229,8 +231,11 @@ class Filler(BaseRecorder):
             lines_len = len(lines)
 
             for i in self._data:
-                now_data = _data_to_list(i[1:], self._before, self._after)
-                row, col = _parse_coord(i[0], col, (list, tuple))
+                if i[0] == 'set_link':
+                    continue
+
+                now_data = self._data_to_list(i[1:])
+                row, col1 = _parse_coord(i[0], col, (list, tuple))
 
                 # 若行数不够，填充行数
                 for _ in range(row - lines_len):
@@ -239,11 +244,11 @@ class Filler(BaseRecorder):
 
                 row_num = row - 1
                 # 若列数不够，填充空列
-                lines[row_num].extend([None] * (col - len(lines[row_num]) + len(now_data) - 1))
+                lines[row_num].extend([None] * (col1 - len(lines[row_num]) + len(now_data) - 1))
 
                 # 填充数据
                 for k, j in enumerate(now_data):
-                    lines[row_num][col + k - 1] = _process_content(j)
+                    lines[row_num][col1 + k - 1] = _process_content(j)
 
             writer = csv_writer(open(self.path, 'w', encoding=self.encoding, newline=''), delimiter=self.delimiter,
                                 quotechar=self.quote_char)
@@ -253,7 +258,7 @@ class Filler(BaseRecorder):
 def _get_xlsx_keys(path: str,
                    begin_row: int,
                    sign_col: Union[int, str],
-                   sign: str,
+                   sign: Union[int, float, str],
                    key_cols: Union[list, tuple]) -> List[list]:
     """返回key列内容，第一位为行号，其余为key列的值       \n
     eg.[3, '名称', 'id']
@@ -285,7 +290,7 @@ def _get_xlsx_keys(path: str,
 def _get_csv_keys(path: str,
                   begin_row: int,
                   sign_col: Union[int, str],
-                  sign: str,
+                  sign: Union[int, float, str],
                   key_cols: Union[list, tuple],
                   encoding: str,
                   delimiter: str,
